@@ -287,12 +287,12 @@ def spread_combinations(contracts):
 
     q = output['Quarterly']
     for qx in ['Q1', 'Q2', 'Q3', 'Q4']:
-        output[qx] = q[[x for x in q if 'Q1' in x]]
+        output[qx] = q[[x for x in q if qx in x]]
     output['Quarterly Spread'] = quarterly_spreads(q)
     q = output['Quarterly Spread']
     for qx in ['Q1-Q2', 'Q2-Q3', 'Q3-Q4', 'Q4-Q1']:
-        output[qx] = q[[x for x in q if 'Q1' in x]]
-    for x in [[1,2], [2,3], [3,4], [4,5], [5,6], [6,7], [7,8], [8,9], [9,10], [10,11], [11,12], [6,6], [12,12], [10,12], [4,9], [10,3]]:
+        output[qx] = q[[x for x in q if qx in x]]
+    for x in [[1,2], [2,3], [3,4], [4,5], [5,6], [6,7], [7,8], [8,9], [9,10], [10,11], [11,12], [12,1], [6,6], [6,12], [12,12], [10,12], [4,9], [10,3]]:
         output['%s-%s' % (x[0], x[1])] = time_spreads(contracts, x[0], x[1])
 
     return output
